@@ -152,13 +152,24 @@ def _load_trinkets() -> typing.List[Trinket]:
                 item["ilevel"],
             ]
         if source == Source.PVP:
-            return list(
-                [
-                    itemlevel
-                    for itemlevel in ItemLevel.PVP
-                    if itemlevel >= item.get("ilevel", 0)
-                ]
-            )
+            if "Aspirant" in item.get("name", None):
+                return list(
+                    [
+                        itemlevel
+                        for itemlevel in ItemLevel.PVP_HONOR
+                        if itemlevel >= item.get("ilevel", 0)
+                    ]
+                )
+            elif "Gladiator" in item.get("name", None):
+                return list(
+                    [
+                        itemlevel
+                        for itemlevel in ItemLevel.PVP_CONQUEST
+                        if itemlevel >= item.get("ilevel", 0)
+                    ]
+                )
+            else:
+                raise ValueError("What the fuck is going on.")
         if source == Source.RARE_MOB:
             return ItemLevel.RARE_MOB.get(item["ilevel"], [item["ilevel"]])
         if source == Source.CALLING:
